#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# Xiang Wang @ 2019-09-29 11:38:43


from rest_framework import mixins, viewsets, pagination, permissions
from . import models, filters, serializers


class PaginationClass(pagination.PageNumberPagination):
    page_size = 10
    page_size_query_param = "page_size"
    max_page_size = 1000


class CouponUserViewSet(mixins.ListModelMixin,
                        viewsets.GenericViewSet):

    queryset = models.CouponUser.objects.all()
    filter_class = filters.CouponUserFilter
    permission_classes = [permissions.IsAuthenticated]

    def get_serializer_class(self):
        serializer_name = "CouponUser{}Serializer".format(
            self.action.capitalize())
        return getattr(serializers, serializer_name)

    def get_queryset(self):
        return models.CouponUser.objects.filter(user=self.request.user)



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# Xiang Wang @ 2019-09-29 12:36:19


import django_filters

from . import models


class CouponUserFilter(django_filters.rest_framework.FilterSet):
    coupon_compagin_name = django_filters.CharFilter(
        field_name="coupon__campaign__name")
    not_redeemed = django_filters.BooleanFilter(
        field_name="redeemed_at",
        lookup_expr="isnull")

    class Meta:
        model = models.CouponUser
        fields = ["coupon", "coupon_compagin_name", "not_redeemed"]



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# Xiang Wang @ 2019-09-29 12:48:05


from . import models
from rest_framework import serializers


class CouponUserListSerializer(serializers.ModelSerializer):

    class Meta:
        model = models.CouponUser
        fields = ["id", "redeemed_at", ]



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
# Xiang Wang @ 2019-09-29 11:37:10

from rest_framework import routers
from . import views


app_name = "coupons"
router = routers.SimpleRouter()
router.register("couponuser", views.CouponUserViewSet)
urlpatterns = router.urls + [

]
